@@ -25,7 +25,7 @@ else :
                                      collate_zeros_padding, make_mask)
     from dstk.pytorch._callback import (CallbackInterface, CallbackHandler,
                                         FitState, FitControl, PrintCallback,
-                                        ProgressBarCallback,
+                                        ProgressBarCallback, Backup,
                                         LRSchedulerCallback,
                                         EarlyStoppingCallback, Supervision,
                                         DEFAULT_CALLBACKS)
@@ -45,6 +45,7 @@ else :
         'FitControl',
         'PrintCallback',
         'ProgressBarCallback',
+        'Backup',
         'EarlyStoppingCallback',
         'LRSchedulerCallback',
         'Supervision',
